@@ -1,7 +1,7 @@
 package t::ExampleProject::KidsShow::OldClown;
 use strict;
 
-sub BeHeavy {
+sub BeHeavy ($){
     my ($KilocaloriesForBreakfast) = @_;
     return $KilocaloriesForBreakfast / 1000; ## no critic (ProhibitMagicNumbers)
 }
